@@ -22,9 +22,11 @@
 *  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
-#include "glpapi.h"
+#include "draft.h"
+#include "env.h"
 #include "glpgmp.h"
-#include "glplib.h"
+#include "misc.h"
+#include "prob.h"
 
 struct csa
 {     /* common storage area */
@@ -100,10 +102,12 @@ struct csa
       /* name of output problem file in CPLEX LP format */
       const char *out_glp;
       /* name of output problem file in GLPK format */
+#if 0
       const char *out_pb;
       /* name of output problem file in OPB format */
       const char *out_npb;
       /* name of output problem file in normalized OPB format */
+#endif
 #if 1 /* 06/VIII-2011 */
       const char *out_cnf;
       /* name of output problem file in DIMACS CNF-SAT format */
@@ -132,6 +136,10 @@ struct csa
       int obj_bnd;
       /* upper (minization) or lower (maximization) objective bound */
 #endif
+#if 1 /* 11/VII-2013 */
+      const char *use_sol;
+      /* name of input mip solution file in GLPK format */
+#endif
 };
 
 static void print_help(const char *my_name)
@@ -309,9 +317,10 @@ static void print_help(const char *my_name)
       xprintf("                     (assumes --intopt)\n");
       xprintf("   --fpump           apply feasibility pump heuristic\n")
          ;
-#if 1 /* 25/V-2013 */
-      xprintf("   --proxy           apply proximity search heuristic\n")
-         ;
+#if 1 /* 29/VI-2013 */
+      xprintf("   --proxy [nnn]     apply proximity search heuristic (n"
+         "nn is time limit\n");
+      xprintf("                     in seconds; default is 60)\n");
 #endif
       xprintf("   --gomory          generate Gomory's mixed integer cut"
          "s\n");
@@ -355,8 +364,8 @@ static void print_version(int briefly)
       xprintf("\n");
       xprintf("Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, "
          "2007, 2008,\n");
-      xprintf("2009, 2010, 2011, 2013 Andrew Makhorin, Department for A"
-         "pplied\n");
+      xprintf("2009, 2010, 2011, 2013, 2014 Andrew Makhorin, Department"
+         " for Applied\n");
       xprintf("Informatics, Moscow Aviation Institute, Moscow, Russia. "
          "All rights\n");
       xprintf("reserved. E-mail: <mao@gnu.org>.\n");
@@ -419,7 +428,7 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
             if (strcmp(argv[k], "?") == 0)
                csa->seed = 0x80000000;
             else if (str2int(argv[k], &csa->seed))
-            {  xprintf("Invalid seed value `%s'\n", argv[k]);
+            {  xprintf("Invalid seed value '%s'\n", argv[k]);
                return 1;
             }
          }
@@ -505,7 +514,7 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
                return 1;
             }
             if (str2int(argv[k], &tm_lim) || tm_lim < 0)
-            {  xprintf("Invalid time limit `%s'\n", argv[k]);
+            {  xprintf("Invalid time limit '%s'\n", argv[k]);
                return 1;
             }
             if (tm_lim <= INT_MAX / 1000)
@@ -521,7 +530,7 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
                return 1;
             }
             if (str2int(argv[k], &mem_lim) || mem_lim < 1)
-            {  xprintf("Invalid memory limit `%s'\n", argv[k]);
+            {  xprintf("Invalid memory limit '%s'\n", argv[k]);
                return 1;
             }
             glp_mem_limit(mem_lim);
@@ -588,6 +597,7 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
             }
             csa->out_glp = argv[k];
          }
+#if 0
          else if (p("--wpb"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
@@ -612,6 +622,7 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
             }
             csa->out_npb = argv[k];
          }
+#endif
 #if 1 /* 06/VIII-2011 */
          else if (p("--wcnf"))
          {  k++;
@@ -728,9 +739,19 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
             csa->iocp.presolve = csa->iocp.binarize = GLP_ON;
          else if (p("--fpump"))
             csa->iocp.fp_heur = GLP_ON;
-#if 1 /* 25/V-2013 */
+#if 1 /* 29/VI-2013 */
          else if (p("--proxy"))
-            csa->iocp.ps_heur = GLP_ON;
+         {  csa->iocp.ps_heur = GLP_ON;
+            if (argv[k+1] && isdigit((unsigned char)argv[k+1][0]))
+            {  int nnn;
+               k++;
+               if (str2int(argv[k], &nnn) || nnn < 1)
+               {  xprintf("Invalid proxy time limit '%s'\n", argv[k]);
+                  return 1;
+               }
+               csa->iocp.ps_tm_lim = 1000 * nnn;
+            }
+         }
 #endif
          else if (p("--gomory"))
             csa->iocp.gmi_cuts = GLP_ON;
@@ -751,7 +772,7 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
                return 1;
             }
             if (str2num(argv[k], &mip_gap) || mip_gap < 0.0)
-            {  xprintf("Invalid relative mip gap tolerance `%s'\n",
+            {  xprintf("Invalid relative mip gap tolerance '%s'\n",
                   argv[k]);
                return 1;
             }
@@ -770,15 +791,41 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
             csa->minisat = 1;
             csa->use_bnd = 1;
             if (str2int(argv[k], &csa->obj_bnd))
-            {  xprintf("Invalid objective bound `%s' (should be integer"
+            {  xprintf("Invalid objective bound '%s' (should be integer"
                   " value)\n", argv[k]);
                return 1;
             }
          }
+#endif
+#if 1 /* 11/VII-2013 */
+         else if (p("--use"))
+         {  k++;
+            if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
+            {  xprintf("No input MIP solution file specified\n");
+               return 1;
+            }
+            if (csa->use_sol != NULL)
+            {  xprintf("Only one input MIP solution file allowed\n");
+               return 1;
+            }
+            csa->use_sol = argv[k];
+         }
+         else if (p("--save"))
+         {  k++;
+            if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
+            {  xprintf("No output MIP solution file specified\n");
+               return 1;
+            }
+            if (csa->iocp.save_sol != NULL)
+            {  xprintf("Only one output MIP solution file allowed\n");
+               return 1;
+            }
+            csa->iocp.save_sol = argv[k];
+         }
 #endif
          else if (argv[k][0] == '-' ||
                  (argv[k][0] == '-' && argv[k][1] == '-'))
-         {  xprintf("Invalid option `%s'; try %s --help\n",
+         {  xprintf("Invalid option '%s'; try %s --help\n",
                argv[k], argv[0]);
             return 1;
          }
@@ -834,8 +881,10 @@ int glp_main(int argc, const char *argv[])
       csa->out_freemps = NULL;
       csa->out_cpxlp = NULL;
       csa->out_glp = NULL;
+#if 0
       csa->out_pb = NULL;
       csa->out_npb = NULL;
+#endif
 #if 1 /* 06/VIII-2011 */
       csa->out_cnf = NULL;
 #endif
@@ -849,6 +898,9 @@ int glp_main(int argc, const char *argv[])
       csa->minisat = 0;
       csa->use_bnd = 0;
       csa->obj_bnd = 0;
+#endif
+#if 1 /* 11/VII-2013 */
+      csa->use_sol = NULL;
 #endif
       /* parse command-line parameters */
       ret = parse_cmdline(csa, argc, argv);
@@ -870,8 +922,10 @@ int glp_main(int argc, const char *argv[])
       if (csa->out_freemps != NULL) remove(csa->out_freemps);
       if (csa->out_cpxlp != NULL) remove(csa->out_cpxlp);
       if (csa->out_glp != NULL) remove(csa->out_glp);
+#if 0
       if (csa->out_pb != NULL) remove(csa->out_pb);
       if (csa->out_npb != NULL) remove(csa->out_npb);
+#endif
 #if 1 /* 06/VIII-2011 */
       if (csa->out_cnf != NULL) remove(csa->out_cnf);
 #endif
@@ -1059,6 +1113,7 @@ err2:    {  xprintf("MathProg model processing error\n");
             goto done;
          }
       }
+#if 0
       /* write problem data in OPB format, if required */
       if (csa->out_pb != NULL)
       {  ret = lpx_write_pb(csa->prob, csa->out_pb, 0, 0);
@@ -1078,6 +1133,7 @@ err2:    {  xprintf("MathProg model processing error\n");
             goto done;
          }
       }
+#endif
 #if 1 /* 06/VIII-2011 */
       /* write problem data in DIMACS CNF-SAT format, if required */
       if (csa->out_cnf != NULL)
@@ -1126,6 +1182,19 @@ err2:    {  xprintf("MathProg model processing error\n");
          }
          goto skip;
       }
+#if 1 /* 11/VII-2013 */
+      /*--------------------------------------------------------------*/
+      /* if initial MIP solution is provided, read it */
+      if (csa->solution == SOL_INTEGER && csa->use_sol != NULL)
+      {  ret = glp_read_mip(csa->prob, csa->use_sol);
+         if (ret != 0)
+         {  xprintf("Unable to read initial MIP solution\n");
+            ret = EXIT_FAILURE;
+            goto done;
+         }
+         csa->iocp.use_sol = GLP_ON;
+      }
+#endif
       /*--------------------------------------------------------------*/
       /* scale the problem data, if required */
       if (csa->scale)
@@ -1191,10 +1260,9 @@ err2:    {  xprintf("MathProg model processing error\n");
       }
 #endif
       else if (csa->solution == SOL_INTEGER)
-      {  if (!csa->iocp.presolve)
-         {  glp_set_bfcp(csa->prob, &csa->bfcp);
+      {  glp_set_bfcp(csa->prob, &csa->bfcp);
+         if (!csa->iocp.presolve)
             glp_simplex(csa->prob, &csa->smcp);
-         }
 #if 0
          csa->iocp.msg_lev = GLP_MSG_DBG;
          csa->iocp.pp_tech = GLP_PP_NONE;
@@ -1256,11 +1324,11 @@ skip: /* postsolve the model, if necessary */
       /* write problem solution in printable format, if required */
       if (csa->out_sol != NULL)
       {  if (csa->solution == SOL_BASIC)
-            ret = lpx_print_sol(csa->prob, csa->out_sol);
+            ret = glp_print_sol(csa->prob, csa->out_sol);
          else if (csa->solution == SOL_INTERIOR)
-            ret = lpx_print_ips(csa->prob, csa->out_sol);
+            ret = glp_print_ipt(csa->prob, csa->out_sol);
          else if (csa->solution == SOL_INTEGER)
-            ret = lpx_print_mip(csa->prob, csa->out_sol);
+            ret = glp_print_mip(csa->prob, csa->out_sol);
          else
             xassert(csa != csa);
          if (ret != 0)
