@@ -1,10 +1,10 @@
-/* glpk.h */
+/* glpk.h (GLPK API) */
 
 /***********************************************************************
 *  This code is part of GLPK (GNU Linear Programming Kit).
 *
 *  Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
-*  2009, 2010, 2011, 2013 Andrew Makhorin, Department for Applied
+*  2009, 2010, 2011, 2013, 2014 Andrew Makhorin, Department for Applied
 *  Informatics, Moscow Aviation Institute, Moscow, Russia. All rights
 *  reserved. E-mail: <mao@gnu.org>.
 *
@@ -34,7 +34,7 @@ extern "C" {
 
 /* library version numbers: */
 #define GLP_MAJOR_VERSION  4
-#define GLP_MINOR_VERSION  51
+#define GLP_MINOR_VERSION  53
 
 typedef struct glp_prob glp_prob;
 /* LP/MIP problem object */
@@ -185,10 +185,17 @@ typedef struct
 #if 1 /* 25/V-2013 */
       int ps_heur;            /* proximity search heuristic */
 #endif
+#if 1 /* 29/VI-2013 */
+      int ps_tm_lim;          /* proxy time limit, milliseconds */
+#endif
+#if 1 /* 11/VII-2013 */
+      int use_sol;            /* use existing solution */
+      const char *save_sol;   /* filename to save every new solution */
+#endif
 #if 1 /* 28/V-2010 */
       int alien;              /* use alien solver */
 #endif
-      double foo_bar[28];     /* (reserved) */
+      double foo_bar[25];     /* (reserved) */
 } glp_iocp;
 
 typedef struct
@@ -487,6 +494,16 @@ double glp_get_col_dual(glp_prob *P, int j);
 int glp_get_unbnd_ray(glp_prob *P);
 /* determine variable causing unboundedness */
 
+#if 1 /* 08/VIII-2013; not documented yet */
+int glp_get_it_cnt(glp_prob *P);
+/* get simplex solver iteration count */
+#endif
+
+#if 1 /* 08/VIII-2013; not documented yet */
+int glp_set_it_cnt(glp_prob *P, int it_cnt);
+/* set simplex solver iteration count */
+#endif
+
 int glp_interior(glp_prob *P, const glp_iptcp *parm);
 /* solve LP problem with the interior-point method */
 
