@@ -22,11 +22,12 @@
 *  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
+#include "env.h"
 #include "glplpf.h"
-#include "glpenv.h"
+
 #define xfault xerror
 
-#define _GLPLPF_DEBUG 0
+#define GLPLPF_DEBUG 0
 
 /* CAUTION: DO NOT CHANGE THE LIMIT BELOW */
 
@@ -54,20 +55,32 @@
 
 LPF *lpf_create_it(void)
 {     LPF *lpf;
-#if _GLPLPF_DEBUG
+#if GLPLPF_DEBUG
       xprintf("lpf_create_it: warning: debug mode enabled\n");
 #endif
       lpf = xmalloc(sizeof(LPF));
       lpf->valid = 0;
       lpf->m0_max = lpf->m0 = 0;
+#if 0 /* 06/VI-2013 */
       lpf->luf = luf_create_it();
+#else
+      lpf->lufint = lufint_create();
+#endif
       lpf->m = 0;
       lpf->B = NULL;
       lpf->n_max = 50;
       lpf->n = 0;
       lpf->R_ptr = lpf->R_len = NULL;
       lpf->S_ptr = lpf->S_len = NULL;
+#if 0 /* 11/VIII-2013 */
       lpf->scf = NULL;
+#else
+      lpf->ifu.n_max = 0;
+      lpf->ifu.n = 0;
+      lpf->ifu.f = NULL;
+      lpf->ifu.u = NULL;
+      lpf->t_opt = 0;
+#endif
       lpf->P_row = lpf->P_col = NULL;
       lpf->Q_row = lpf->Q_col = NULL;
       lpf->v_size = 1000;
@@ -128,7 +141,7 @@ LPF *lpf_create_it(void)
 int lpf_factorize(LPF *lpf, int m, const int bh[], int (*col)
       (void *info, int j, int ind[], double val[]), void *info)
 {     int k, ret;
-#if _GLPLPF_DEBUG
+#if GLPLPF_DEBUG
       int i, j, len, *ind;
       double *B, *val;
 #endif
@@ -149,8 +162,22 @@ int lpf_factorize(LPF *lpf, int m, const int bh[], int (*col)
          lpf->S_ptr = xcalloc(1+lpf->n_max, sizeof(int));
       if (lpf->S_len == NULL)
          lpf->S_len = xcalloc(1+lpf->n_max, sizeof(int));
+#if 0 /* 11/VIII-2013 */
       if (lpf->scf == NULL)
          lpf->scf = scf_create_it(lpf->n_max);
+#else
+      if (lpf->ifu.n_max == 0)
+      {  int n_max = lpf->n_max;
+         lpf->ifu.n_max = n_max;
+         lpf->ifu.n = 0;
+         xassert(n_max > 0);
+         xassert(lpf->ifu.f == NULL);
+         lpf->ifu.f = talloc(n_max * n_max, double);
+         xassert(lpf->ifu.u == NULL);
+         lpf->ifu.u = talloc(n_max * n_max, double);
+         lpf->t_opt = 0;
+      }
+#endif
       if (lpf->v_ind == NULL)
          lpf->v_ind = xcalloc(1+lpf->v_size, sizeof(int));
       if (lpf->v_val == NULL)
@@ -171,6 +198,7 @@ int lpf_factorize(LPF *lpf, int m, const int bh[], int (*col)
          lpf->work2 = xcalloc(1+lpf->m0_max+lpf->n_max, sizeof(double));
       }
       /* try to factorize the basis matrix */
+#if 0 /* 06/VI-2013 */
       switch (luf_factorize(lpf->luf, m, col, info))
       {  case 0:
             break;
@@ -183,9 +211,15 @@ int lpf_factorize(LPF *lpf, int m, const int bh[], int (*col)
          default:
             xassert(lpf != lpf);
       }
+#else
+      if (lufint_factorize(lpf->lufint, m, col, info) != 0)
+      {  ret = LPF_ESING;
+         goto done;
+      }
+#endif
       /* the basis matrix has been successfully factorized */
       lpf->valid = 1;
-#if _GLPLPF_DEBUG
+#if GLPLPF_DEBUG
       /* store the basis matrix for debugging */
       if (lpf->B != NULL) xfree(lpf->B);
       xassert(m <= 32767);
@@ -211,7 +245,11 @@ int lpf_factorize(LPF *lpf, int m, const int bh[], int (*col)
       /* B = B0, so there are no additional rows/columns */
       lpf->n = 0;
       /* reset the Schur complement factorization */
+#if 0 /* 11/VIII-2013 */
       scf_reset_it(lpf->scf);
+#else
+      lpf->ifu.n = 0;
+#endif
       /* P := Q := I */
       for (k = 1; k <= m; k++)
       {  lpf->P_row[k] = lpf->P_col[k] = k;
@@ -352,7 +390,7 @@ static void st_prod(LPF *lpf, double y[], double a, const double x[])
       return;
 }
 
-#if _GLPLPF_DEBUG
+#if GLPLPF_DEBUG
 /***********************************************************************
 *  The routine check_error computes the maximal relative error between
 *  left- and right-hand sides for the system B * x = b (if tr is zero)
@@ -475,13 +513,13 @@ void lpf_ftran(LPF *lpf, double x[])
       double *f = fg;
       double *g = fg + m0;
       int i, ii;
-#if _GLPLPF_DEBUG
+#if GLPLPF_DEBUG
       double *b;
 #endif
       if (!lpf->valid)
          xfault("lpf_ftran: the factorization is not valid\n");
       xassert(0 <= m && m <= m0 + n);
-#if _GLPLPF_DEBUG
+#if GLPLPF_DEBUG
       /* save the right-hand side vector */
       b = xcalloc(1+m, sizeof(double));
       for (i = 1; i <= m; i++) b[i] = x[i];
@@ -490,18 +528,33 @@ void lpf_ftran(LPF *lpf, double x[])
       for (i = 1; i <= m0 + n; i++)
          fg[i] = ((ii = P_col[i]) <= m ? x[ii] : 0.0);
       /* f1 := inv(L0) * f */
+#if 0 /* 06/VI-2013 */
       luf_f_solve(lpf->luf, 0, f);
+#else
+      luf_f_solve(lpf->lufint->luf, f);
+#endif
       /* g1 := g - S * f1 */
       s_prod(lpf, g, -1.0, f);
       /* g2 := inv(C) * g1 */
+#if 0 /* 11/VIII-2013 */
       scf_solve_it(lpf->scf, 0, g);
+#else
+      ifu_a_solve(&lpf->ifu, g, lpf->work2);
+#endif
       /* f2 := inv(U0) * (f1 - R * g2) */
       r_prod(lpf, f, -1.0, g);
+#if 0 /* 06/VI-2013 */
       luf_v_solve(lpf->luf, 0, f);
+#else
+      {  double *work = lpf->lufint->sgf->work;
+         luf_v_solve(lpf->lufint->luf, f, work);
+         memcpy(&f[1], &work[1], m0 * sizeof(double));
+      }
+#endif
       /* (x y) := inv(Q) * (f2 g2) */
       for (i = 1; i <= m; i++)
          x[i] = fg[Q_col[i]];
-#if _GLPLPF_DEBUG
+#if GLPLPF_DEBUG
       /* check relative error in solution */
       check_error(lpf, 0, x, b);
       xfree(b);
@@ -605,13 +658,13 @@ void lpf_btran(LPF *lpf, double x[])
       double *f = fg;
       double *g = fg + m0;
       int i, ii;
-#if _GLPLPF_DEBUG
+#if GLPLPF_DEBUG
       double *b;
 #endif
       if (!lpf->valid)
          xfault("lpf_btran: the factorization is not valid\n");
       xassert(0 <= m && m <= m0 + n);
-#if _GLPLPF_DEBUG
+#if GLPLPF_DEBUG
       /* save the right-hand side vector */
       b = xcalloc(1+m, sizeof(double));
       for (i = 1; i <= m; i++) b[i] = x[i];
@@ -620,19 +673,34 @@ void lpf_btran(LPF *lpf, double x[])
       for (i = 1; i <= m0 + n; i++)
          fg[i] = ((ii = Q_row[i]) <= m ? x[ii] : 0.0);
       /* f1 := inv(U'0) * f */
+#if 0 /* 06/VI-2013 */
       luf_v_solve(lpf->luf, 1, f);
+#else
+      {  double *work = lpf->lufint->sgf->work;
+         luf_vt_solve(lpf->lufint->luf, f, work);
+         memcpy(&f[1], &work[1], m0 * sizeof(double));
+      }
+#endif
       /* g1 := inv(C') * (g - R' * f1) */
       rt_prod(lpf, g, -1.0, f);
+#if 0 /* 11/VIII-2013 */
       scf_solve_it(lpf->scf, 1, g);
+#else
+      ifu_at_solve(&lpf->ifu, g, lpf->work2);
+#endif
       /* g2 := g1 */
       g = g;
       /* f2 := inv(L'0) * (f1 - S' * g2) */
       st_prod(lpf, f, -1.0, g);
+#if 0 /* 06/VI-2013 */
       luf_f_solve(lpf->luf, 1, f);
+#else
+      luf_ft_solve(lpf->lufint->luf, f);
+#endif
       /* (x y) := P * (f2 g2) */
       for (i = 1; i <= m; i++)
          x[i] = fg[P_row[i]];
-#if _GLPLPF_DEBUG
+#if GLPLPF_DEBUG
       /* check relative error in solution */
       check_error(lpf, 1, x, b);
       xfree(b);
@@ -811,7 +879,7 @@ int lpf_update_it(LPF *lpf, int j, int bh, int len, const int ind[],
       const double val[])
 {     int m0 = lpf->m0;
       int m = lpf->m;
-#if _GLPLPF_DEBUG
+#if GLPLPF_DEBUG
       double *B = lpf->B;
 #endif
       int n = lpf->n;
@@ -860,7 +928,7 @@ int lpf_update_it(LPF *lpf, int j, int bh, int len, const int ind[],
                "ed\n", k, val[k]);
          a[i] = val[k];
       }
-#if _GLPLPF_DEBUG
+#if GLPLPF_DEBUG
       /* change column in the basis matrix for debugging */
       for (i = 1; i <= m; i++)
          B[(i - 1) * m + j] = a[i];
@@ -872,9 +940,20 @@ int lpf_update_it(LPF *lpf, int j, int bh, int len, const int ind[],
       for (i = 1; i <= m0+n; i++) vw[i] = 0.0;
       vw[Q_col[j]] = 1.0;
       /* f1 := inv(L0) * f (new column of R) */
+#if 0 /* 06/VI-2013 */
       luf_f_solve(lpf->luf, 0, f);
+#else
+      luf_f_solve(lpf->lufint->luf, f);
+#endif
       /* v1 := inv(U'0) * v (new row of S) */
+#if 0 /* 06/VI-2013 */
       luf_v_solve(lpf->luf, 1, v);
+#else
+      {  double *work = lpf->lufint->sgf->work;
+         luf_vt_solve(lpf->lufint->luf, v, work);
+         memcpy(&v[1], &work[1], m0 * sizeof(double));
+      }
+#endif
       /* we need at most 2 * m0 available locations in the SVA to store
          new column of matrix R and new row of matrix S */
       if (lpf->v_size < v_ptr + m0 + m0)
@@ -906,6 +985,7 @@ int lpf_update_it(LPF *lpf, int j, int bh, int len, const int ind[],
       z = 0.0;
       for (i = 1; i <= m0; i++) z -= v[i] * f[i];
       /* update factorization of new matrix C */
+#if 0 /* 11/VIII-2013 */
       switch (scf_update_exp(lpf->scf, x, y, z))
       {  case 0:
             break;
@@ -918,6 +998,36 @@ int lpf_update_it(LPF *lpf, int j, int bh, int len, const int ind[],
          default:
             xassert(lpf != lpf);
       }
+#else
+      if (lpf->t_opt == SCF_TBG)
+      {  if (ifu_bg_update(&lpf->ifu, x, y, z) != 0)
+#if 0
+         {  xprintf("Warning: insufficient accuracy (Bartels-Golub upda"
+               "te)\n");
+#else
+         {
+#endif
+            lpf->valid = 0;
+            ret = LPF_ESING;
+            goto done;
+         }
+      }
+      else if (lpf->t_opt == SCF_TGR)
+      {  if (ifu_gr_update(&lpf->ifu, x, y, z) != 0)
+#if 0
+         {  xprintf("Warning: insufficient accuracy (Givens rotations u"
+               "pdate)\n");
+#else
+         {
+#endif
+            lpf->valid = 0;
+            ret = LPF_ESING;
+            goto done;
+         }
+      }
+      else
+         xassert(lpf != lpf);
+#endif
       /* expand matrix P */
       P_row[m0+n+1] = P_col[m0+n+1] = m0+n+1;
       /* expand matrix Q */
@@ -952,8 +1062,12 @@ done: /* return to the calling program */
 *  object. */
 
 void lpf_delete_it(LPF *lpf)
+#if 0 /* 06/VI-2013 */
 {     luf_delete_it(lpf->luf);
-#if _GLPLPF_DEBUG
+#else
+{     lufint_delete(lpf->lufint);
+#endif
+#if GLPLPF_DEBUG
       if (lpf->B != NULL) xfree(lpf->B);
 #else
       xassert(lpf->B == NULL);
@@ -962,7 +1076,12 @@ void lpf_delete_it(LPF *lpf)
       if (lpf->R_len != NULL) xfree(lpf->R_len);
       if (lpf->S_ptr != NULL) xfree(lpf->S_ptr);
       if (lpf->S_len != NULL) xfree(lpf->S_len);
+#if 0 /* 11/VIII-2013 */
       if (lpf->scf != NULL) scf_delete_it(lpf->scf);
+#else
+      if (lpf->ifu.f != NULL) tfree(lpf->ifu.f);
+      if (lpf->ifu.u != NULL) tfree(lpf->ifu.u);
+#endif
       if (lpf->P_row != NULL) xfree(lpf->P_row);
       if (lpf->P_col != NULL) xfree(lpf->P_col);
       if (lpf->Q_row != NULL) xfree(lpf->Q_row);
